@@ -23,12 +23,16 @@ Would result in:
     a = arguments[0]
     b = arguments[1]
 
-    # Check that both args are arrays.
-    unless a.is_a?(Array) and b.is_a?(Array)
+    # Check that the first parameter is an array
+    unless a.is_a?(Array)
       raise(Puppet::ParseError, 'concat(): Requires array to work with')
     end
 
-    result = a.concat(b)
+    if b.is_a?(Array)
+      result = a.concat(b)
+    else
+      result = a << b
+    end
 
     return result
   end
