@@ -1,6 +1,4 @@
-
 Puppet::Type.type(:file_line).provide(:ruby) do
-
   def exists?
     lines.find do |line|
       line.chomp == resource[:line].chomp
@@ -9,9 +7,11 @@ Puppet::Type.type(:file_line).provide(:ruby) do
 
   def create
     if resource[:match]
-      handle_create_with_match()
+      handle_create_with_match
+    elsif resource[:after]
+      handle_create_with_after
     else
-      handle_create_without_match()
+      append_line
     end
   end
 
@@ -35,8 +35,8 @@ Puppet::Type.type(:file_line).provide(:ruby) do
   def handle_create_with_match()
     regex = resource[:match] ? Regexp.new(resource[:match]) : nil
     match_count = lines.select { |l| regex.match(l) }.size
-    if match_count > 1
-      raise Puppet::Error, "More than one line in file '#{resource[:path]}' matches pattern '#{resource[:match]}'"
+    if match_count > 1 && resource[:multiple].to_s != 'true'
+     raise Puppet::Error, "More than one line in file '#{resource[:path]}' matches pattern '#{resource[:match]}'"
     end
     File.open(resource[:path], 'w') do |fh|
       lines.each do |l|
@@ -49,11 +49,35 @@ Puppet::Type.type(:file_line).provide(:ruby) do
     end
   end
 
-  def handle_create_without_match
+  def handle_create_with_after
+    regex = Regexp.new(resource[:after])
+
+    count = lines.count {|l| l.match(regex)}
+
+    case count
+    when 1 # find the line to put our line after
+      File.open(resource[:path], 'w') do |fh|
+        lines.each do |l|
+          fh.puts(l)
+          if regex.match(l) then
+            fh.puts(resource[:line])
+          end
+        end
+      end
+    when 0 # append the line to the end of the file
+      append_line
+    else
+      raise Puppet::Error, "#{count} lines match pattern '#{resource[:after]}' in file '#{resource[:path]}'.  One or no line must match the pattern."
+    end
+  end
+
+  ##
+  # append the line to the file.
+  #
+  # @api private
+  def append_line
     File.open(resource[:path], 'a') do |fh|
       fh.puts resource[:line]
     end
   end
-
-
 end
